const RootTypes = `
    # Requêtes
    type Query {
        accessGroups : GroupQuery
        accessPosts : MessageQuery
        accessUsers : UserQuery

        asAdmin(groupUID: ID): AdminQuery
        asSpeaker(groupUID: ID): AdminQuery
        asMember(groupUID: ID): MemberQuery
        asViewer(groupUID: ID): AdminQuery
        
    }

    type Mutation {
        asSuperviser(groupUID: String): SuperviserMutation
        asAdmin(groupUID: String): AdminMutation
        asSpeaker(groupUID: String): SpeakerMutation
        asMember(groupUID: String): MemberMutation
        asViewer(groupUID: String): ViewerMutation
    }

   
`;

const subMutations = `

    type SuperviserMutation {
        runAdminOperation : AdminMutation
        takeAdminRights : Group
    }

    type AdminMutation {

        isAdmin: Boolean

        createSubgroup(
            uid: ID = null,
            name: String,
            website: String,
            description: String,
            school: String
        ): Group

        addUser(userid : String): User
        removeUser(userid : String): User
        addAdmin(userid : String): User
        removeAdmin(userid : String): User

        editGroup(
            name: String,
            website: String,
            description: String,
            school: String
        ): Group

    }

    type SpeakerMutation{
        postEvent(name: String, date: String): Event
        answerEventRequest(request: ID, accept : Boolean): Request
    }

    type MemberMutation {
        leave: Group
    }

    type ViewerMutation {
        requestJoin: Group
    }


`;

const subQueries = `

    """
    Requête pour obtenir un groupe.
    """
    type GroupQuery{
        allGroups: [Group]
        allSimpleGroups: [SimpleGroup]

        group(uid: ID) : Group
        simpleGroup(uid : ID) : SimpleGroup
        metaGroup(uid : ID) : MetaGroup

    }

    """
    Requête pour obtenir un message.
    """
    type MessageQuery{
        allMessages: [Message]
        allEvents: [Event]
        allPosts: [Post]
        message(id: ID): Message
        allAnnouncements: [Announcement]
    }

    type UserQuery{

        user(uid: ID) : User

        searchTOL(
            givenName: String,
            lastName: String,
            nickname: String,
            nationality: String,
            school: String,
            promotion: String,
            groups: String,
            studies: String,
            sport: String,
            phone: String,
            mail: String,
            adress: String,
            ip: String
        ): [String]
    }

    # Requête à la base de donnée nécessitant d'être administrateur.
    type AdminQuery{
        isAdmin: Boolean
        allRequests : [Request]
    }

    type SpeakerQuery{
        isSpeaker: Boolean
        allRequests : [Request]
    }

    type MemberQuery{
        isMember: Boolean
        allMembers : [Group]
    }

    type ViewerQuery{
        isViewer: Boolean
    }
`;

const actionDefs = [RootTypes, subQueries, subMutations ];
export default actionDefs;
